#!/bin/sh
VER=2
MIRROR_DIR=/var/www/manager/mirror
MIRROR_PRODUCT_LIST=$MIRROR_DIR/products.lst
TARGET=/var/www/manager/update/latest
PROXY_SETTING="$MIRROR_DIR/proxy.conf"
LOG_LEVEL="local3.info"
RC=0

if [ ! -f "$MIRROR_PRODUCT_LIST" ]
then
	echo "product list file not exist"
	logger -i -p $LOG_LEVEL -t PSMTmirror -- "PSMT mirror failed. A product list file not exist."
	exit 1
fi

if [ -f $PROXY_SETTING ]
then
	PROXY_CONF=`cat $PROXY_SETTING`
else
	PROXY_CONF=""
fi

if [ ! -d $TARGET ]
then
	mkdir $TARGET
fi

rm $TARGET/version.txt > /dev/null 2>&1
rm $TARGET/VERSION > /dev/null 2>&1

exec 3<&0  < $MIRROR_PRODUCT_LIST
while read product
do
	case ${product} in
		clamav)
			MIRROR_CMD="clamav_mirror.pl --target=$TARGET"
			LANG=C
			export LANG
			;;
		pse5)
			MIRROR_CMD=proscan_mirror.sh
			;;
		psps6)
			MIRROR_CMD=proscan_mirror_ppc.sh
			;;
		psaix)
			MIRROR_CMD=proscan_mirror_aix.sh
			;;
		pssx6)
			MIRROR_CMD=proscan_mirror_x86.sh
			;;
		psmt2)
			MIRROR_CMD=psmt2_mirror.sh
			;;
		psmt2.1)
			MIRROR_CMD=psmt2.1_mirror.sh
			;;
		psmt2.3)
			MIRROR_CMD=psmt2.3_mirror.sh
			;;
		antispam)
			MIRROR_CMD=antispam_mirror.sh
			;;
		*)
			echo "unknown product: $product"
			RC=1
			;;
	esac
	$MIRROR_DIR/$MIRROR_CMD $PROXY_CONF $TARGET
	RC=`expr $RC + $?`
done
exec 0<&3 3<&-

if [ ! -f "$TARGET/VERSION" -a -f "$TARGET/version.txt" ]
then
	RC=0
fi

if [ $RC -eq 0 ]
then
	exec 3<&0 < $TARGET/version.txt
	while read ver
	do
		TYPE=`echo $ver|cut -d '=' -f1`
		VER=`echo $ver|cut -d '=' -f2`
		case $TYPE in
			clamav)
				CLAMAV=$VER
				;;
			pse5)
				PROSCAN=$VER
				;;
			psps6)
				PROSCAN=$VER
				;;
			pssx6)
				PROSCAN=$VER
				;;
			psaix)
				PROSCAN=$VER
				;;
			*)
				;;
		esac
	done
	exec 0<&3 3<&-
	
	DATE=`date +"%Y/%m/%d,%X"`
	echo "$PROSCAN,$CLAMAV,$DATE" > $TARGET/VERSION
else
	logger -i -p $LOG_LEVEL -t PSMTmirror -- "PSMT mirror failed. See detail logfile."
fi

find $TARGET -mtime +30 -name "*.cdiff" -exec rm {} \; > /dev/null 2>&1
chown -R psmtadm:psmtadm $TARGET

exit $RC
